<?php

namespace Drp\ProjectHelpers\Tests\Concerns;

use Drp\ProjectHelpers\Tests\Helpers\Hasher;
use Illuminate\Support\Manager;

trait HasFakeHasher
{
    /**
     * Swap out the Laravel Hasher with the fake Hasher
     * This will drastically increase test speed as no
     * passwords are actually hashed
     *
     * @return void
     */
    public function userFakeHasher()
    {
        $hasher = app('hash');

        /**
         * Laravel >5.6 implementation uses a HasherFactory
         */
        if ($hasher instanceof Manager) {

            config(['hashing.driver' => 'fakeHasher']);

            $hasher->extend('fakeHasher', function () {
                return new Hasher;
            });

            return;
        }

        /**
         * Laravel <5.5 implementation
         */
        app()->alias(Hasher::class, 'hash');
    }
}